#!/bin/sh
#
# P5 de-installation script.
#
# See the file "license.txt" for information on usage and
# redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#
# Rcsid: @(#)$Id: uninstall.sh,v 1.16 2017/07/26 11:02:04 zv Exp $
# ----------------------------------------------------------------------
#

#
# Test for root user.
#

case `uname -s` in
  SunOS)
    id=/usr/xpg4/bin/id
    ;;
  *)
    id=/usr/bin/id
    ;;
esac
if test `$id -u` -ne 0; then
    echo "Uninstalling P5 can only be done as user root!" >&2
    exit 1
fi

#
# Get home directory
#

dir=`dirname "$0"`
cwd=`pwd`;cd "$dir"
LEXXDIR=`pwd`;export LEXXDIR
cd "$cwd"

#
# Locate the startup directory
#

case `uname -s` in
    Linux)
        for dir in /etc/rc.d /sbin/init.d; do
            if test -d $dir; then
                rcdir=$dir
                break
            fi
        done
    ;;
    SunOS)
        rcdir=/etc
    ;;
    FreeBSD)
	rcdir=
    ;;
    Darwin)
        rcdir=/Library/StartupItems
    ;;
    *)
        echo "unsupported platform: `uname -s`"
        exit 1
    ;;
esac

"$LEXXDIR/ping-server" >/dev/null 2>&1
if test $? -eq 0; then
    echo ""
    echo "NOTE: The P5 application server is still runing!"
    echo "You should stop the server with \"stop-server\" script"
    echo "before uninstalling any P5 files from this system."
    echo ""
    exit 1
fi

ans="n"
mrk=0
echo ""
echo "This script removes P5 scripts from startup directories."
printf "Do you really like to do this (y/n) [n]: "
read ans
if test "x"$ans = "xy"; then
    mrk=1
    printf "Removing auto-start traces from system startup directories... "
    case `uname -s` in
        Darwin)
	    rm -f /etc/pam.d/nsd
	    rm -f /var/log/awlogs
            rm -rf /Library/PreferencePanes/PresSTORE.prefPane
            rm -f $rcdir/PresStore
            rm -f /Library/LaunchDaemons/com.archiware.presstore*
        ;;
        FreeBSD)
	    rm -f /etc/pam.d/nsd
            rm -f /etc/rc.d/lexx
            grep -v lexx_enable /etc/rc.conf > /tmp/$$; mv /tmp/$$ /etc/rc.conf
        ;;
        Linux|SunOS)
	    rm -f /etc/pam.d/nsd
            rm -f /etc/init.d/lexx
            if test -x /usr/sbin/update-rc.d; then
                /usr/sbin/update-rc.d lexx remove
            else
                for i in 0 1 2 3 5 6 S; do
                    if test -d $rcdir/rc$i.d; then
                        rm -f $rcdir/rc$i.d/S*lexx
                        rm -f $rcdir/rc$i.d/K*lexx
                    fi
                done
            fi
        ;;
    esac
    echo "done."
fi

#
# Remove changer driver
#

if test `uname -s` = "SunOS"; then
    ans="n"
    echo ""
    echo "This script removes the changer driver from the running system."
    printf "Do you really like to do this (y/n) [n]: "
    read ans
    if test "x"$ans = "xy"; then
        mrk=1
        printf "Removing driver files and unloading the driver... "
        dr=/kernel/drv
        rem_drv awjb 1>&2 2>/dev/null
        rm -f $dr/awjb $dr/sparcv9/awjb $dr/awjb.conf
        echo "done."
    fi
fi

#
# Final message
#

if test $mrk -eq 0; then
    echo ""
    echo "No actions performed, exiting."
else
    echo ""
    echo "You may now delete all files from directory:"
    echo ""
    echo "    \"$LEXXDIR\""
    echo ""
    echo "This removes last traces of P5 from this system."
    echo ""
    echo "Thank you for using/evaluating P5 product."
    echo "The Archiware P5 Team (http://www.archiware.com)."
    echo ""
fi

exit 0

# EOF $RCSfile: uninstall.sh,v $
